# Examples

This directory contains self-contained examples of how to use kani to do a variety of tasks.

Most of these examples (the ones starting with a number) are taken from the kani docs - give them a read!
